==> kdepim-runtime-4.8.1.tar.xz: kdepim-runtime-4.8.1/resources/contacts/wizard/contactswizard.es.cmake <==
/*
    Copyright (c) 2010 Tobias Koenig <tokoe@kde.org>

    This library is free software; you can redistribute it and/or modify it
    under the terms of the GNU Library General Public License as published by
    the Free Software Foundation; either version 2 of the License, or (at your
    option) any later version.

    This library is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
    License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to the
    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
    02110-1301, USA.
*/

// TODO: i18n??
var page = Dialog.addPage( "contactswizard.ui", "Settings" );

page.widget().lineEdit.text = "${CONTACTS_DIRECTORY_DEFAULT_PATH}";

function validateInput()
{
  if ( page.widget().lineEdit.text == "" ) {
    page.setValid( false );
  } else {
    page.setValid( true );
  }
}

function setup()
{
  var contactsResource = SetupManager.createResource( "akonadi_contacts_resource" );
  contactsResource.setOption( "Path", page.widget().lineEdit.text );
  contactsResource.setOption( "IsConfigured", "true" );
  contactsResource.setName( "Local Contacts" ); //TODO: i18n
  SetupManager.execute();
}

page.widget().lineEdit.textChanged.connect( validateInput );
page.pageLeftNext.connect( setup );
validateInput();

==> kdepim-runtime-4.14.10.tar.xz: kdepim-runtime-4.14.10/resources/contacts/wizard/contactswizard.es.cmake <==
/*
    Copyright (c) 2010 Tobias Koenig <tokoe@kde.org>

    This library is free software; you can redistribute it and/or modify it
    under the terms of the GNU Library General Public License as published by
    the Free Software Foundation; either version 2 of the License, or (at your
    option) any later version.

    This library is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
    License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to the
    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
    02110-1301, USA.
*/

var page = Dialog.addPage( "contactswizard.ui", qsTr("Settings") );

page.widget().lineEdit.text = "${CONTACTS_DIRECTORY_DEFAULT_PATH}";

function validateInput()
{
  if ( page.widget().lineEdit.text == "" ) {
    page.setValid( false );
  } else {
    page.setValid( true );
  }
}

function setup()
{
  var contactsResource = SetupManager.createResource( "akonadi_contacts_resource" );
  contactsResource.setOption( "Path", page.widget().lineEdit.text );
  contactsResource.setOption( "IsConfigured", "true" );
  contactsResource.setName( qsTr("Local Contacts") );
  SetupManager.execute();
}

page.widget().lineEdit.textChanged.connect( validateInput );
page.pageLeftNext.connect( setup );
validateInput();
